@@ -1,4 +1,4 @@
 from .build import program_build
 from .main import program, program_main
+from .merge import program_merge
 from .start import program_start
-from .sync import program_sync
